summaryrefslogtreecommitdiff
path: root/src/theory/theory_model.cpp
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2018-05-10 11:25:19 -0700
committerGitHub <noreply@github.com>2018-05-10 11:25:19 -0700
commit31a2135f4650a63fa772f001fcf191f2f7093a8d (patch)
tree1d01c094b7df9b010f748905aeaace44f17d904a /src/theory/theory_model.cpp
parentaef0e5ed90b1b8913b5c8c743cbcd012d5916ba7 (diff)
Refactored BVAckermann preprocessing pass. (#1889)
Diffstat (limited to 'src/theory/theory_model.cpp')
-rw-r--r--src/theory/theory_model.cpp12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/theory/theory_model.cpp b/src/theory/theory_model.cpp
index 4b603d02a..35ada798c 100644
--- a/src/theory/theory_model.cpp
+++ b/src/theory/theory_model.cpp
@@ -184,7 +184,8 @@ Node TheoryModel::getModelValue(TNode n, bool hasBoundVars, bool useDontCares) c
ret = nr;
}
} else {
// FIXME : special case not necessary? (also address BV_ACKERMANIZE functions below), github issue #1116
if(n.getKind() == kind::LAMBDA) {
NodeManager* nm = NodeManager::currentNM();
Node body = getModelValue(n[1], true);
@@ -198,10 +199,11 @@ Node TheoryModel::getModelValue(TNode n, bool hasBoundVars, bool useDontCares) c
d_modelCache[n] = ret;
return ret;
}
-
- if (n.getNumChildren() > 0 &&
- n.getKind() != kind::BITVECTOR_ACKERMANIZE_UDIV &&
- n.getKind() != kind::BITVECTOR_ACKERMANIZE_UREM) {
+
+ if (n.getNumChildren() > 0
+ && n.getKind() != kind::BITVECTOR_ACKERMANNIZE_UDIV
+ && n.getKind() != kind::BITVECTOR_ACKERMANNIZE_UREM)
+ {
Debug("model-getvalue-debug") << "Get model value children " << n << std::endl;
std::vector<Node> children;
if (n.getKind() == APPLY_UF) {
@@ -184,7 +184,8 @@ Node TheoryModel::getModelValue(TNode n, bool hasBoundVars, bool useDontCares) c
}
} else {
- // FIXME : special case not necessary? (also address BV_ACKERMANIZE functions below), github issue #1116
+ // FIXME : special case not necessary? (also address BV_ACKERMANNIZE
+ // functions below), github issue #1116
if(n.getKind() == kind::LAMBDA) {
NodeManager* nm = NodeManager::currentNM();
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback